@@ -1,14 +1,27 @@
 # -*- coding: UTF-8 -*-
 try:
-    from pyuts.py_mix.asyncU import AsyncU
+    from pyuts.py_file.fileU import FileU
 
-    def asyncU(key=None) -> AsyncU:
+    def fileU(key=None) -> FileU:
         '''
         
-        异步相关工具
+        文件相关工具
         
         '''
-        return AsyncU.produce(key)
+        return FileU.produce(key)
+except ImportError as e:
+    print(e)
+
+try:
+    from pyuts.py_recg.imgU import ImgU
+
+    def imgU(key=None) -> ImgU:
+        '''
+        
+        图片相关工具
+        
+        '''
+        return ImgU.produce(key)
 except ImportError as e:
     print(e)
 
@@ -25,6 +38,32 @@ try:
 except ImportError as e:
     print(e)
 
+try:
+    from pyuts.py_phone.phoneAutoU import PhoneAutoU
+
+    def phoneAutoU(key=None) -> PhoneAutoU:
+        '''
+        
+        手机自动化相关工具
+        
+        '''
+        return PhoneAutoU.produce(key)
+except ImportError as e:
+    print(e)
+
+try:
+    from pyuts.py_mix.asyncU import AsyncU
+
+    def asyncU(key=None) -> AsyncU:
+        '''
+        
+        异步相关工具
+        
+        '''
+        return AsyncU.produce(key)
+except ImportError as e:
+    print(e)
+
 try:
     from pyuts.py_crawl.chromeU import ChromeU
 
@@ -329,19 +368,6 @@ try:
 except ImportError as e:
     print(e)
 
-try:
-    from pyuts.py_file.fileU import FileU
-
-    def fileU(key=None) -> FileU:
-        '''
-        
-        文件相关工具
-        
-        '''
-        return FileU.produce(key)
-except ImportError as e:
-    print(e)
-
 try:
     from pyuts.py_db.redisDBU import RedisDBU
 
