@@ -4,10 +4,9 @@ import importlib
 from .py_api_b import PyApiB
 import os
 """
-用于生成__init__.py文件内容。提交时调用：python -m pyuts.__setup__,如果代码有变化，会重新生成__init__.py
+用于生成__init__.py文件内容。提交时调用：rm -f ./pyuts/__init__.py && python3 -m pyuts.__setup__,如果代码有变化，会重新生成__init__.py
 """
 
-
 def load_module(handlers):
     cwd = os.path.dirname(os.path.abspath(handlers.__file__))
     files = os.listdir(cwd)
