@@ -1,6 +1,7 @@
 # -*- coding: UTF-8 -*-
 import pyuts
-from pyuts import MongoDBU
+from pyuts.py_db.mongoDBU import MongoDBU
+
 
 
 class ScrapyprojectnamePipeline(object):
