@@ -1,5 +1,6 @@
 # -*- coding:UTF-8 -*-
-from pyuts import ScrapySpiderU, ScrapyItemU
+from pyuts.py_crawl.scrapySpiderU import ScrapySpiderU
+from pyuts.py_crawl.scrapyItemU import ScrapyItemU
 
 
 class ScrapyspidernameItem(ScrapyItemU):
