@@ -18,6 +18,7 @@ class MongoDBU(PyApiB):
         return PyApiB._produce(key, __class__)
 
     def __init__(self):
+        self.mongo = None
         self.initByEnv() or self.initByEnvFile()
         
     def initByEnv(self):
@@ -44,14 +45,21 @@ class MongoDBU(PyApiB):
 
     def init(self, host=None, port=None, user=None, pswd=None):
         self.session = None
-        if user:
-            self.mongo = MongoClient(f"mongodb://{user}:{pswd}@{host}:{port}")
-        elif host:
-            self.mongo = MongoClient(host, port)
-        else:
-            self.mongo = None
+        if self.hasInit():
+            if user:
+                self.mongo = MongoClient(f"mongodb://{user}:{pswd}@{host}:{port}")
+            elif host:
+                self.mongo = MongoClient(host, port)
+            else:
+                self.mongo = None
         return self
 
+    def hasInit(self):
+        import os
+        if "none_mongo_host" in os.environ and os.environ["none_mongo_host"] == "true":
+            return False
+        return True
+
     def getDatabase(self, dbName):
         return self.mongo.get_database(dbName)
 
