@@ -5,8 +5,8 @@ import string
 import datetime
 import pymysql
 import pymysql.cursors
-from DBUtils.PooledDB import PooledDB
-from DBUtils.SteadyDB import SteadyDBConnection, SteadyDBCursor
+from dbutils.pooled_db import PooledDB
+from dbutils.steady_db import SteadyDBConnection, SteadyDBCursor
 from ..py_mix.envU import EnvU
 envU = EnvU()
 
