@@ -87,6 +87,9 @@ class RedisDBU(PyApiB):
     def get_str_list(self, key):
         """ 获取字符串列表 """
         return self.r.lrange(key,0,-1)
+    
+    def lrange(self, key, s, e):
+        return self.r.lrange(key,s,e)
         
     def set_json_list(self, key, values):
         """ 设置json列表 """
