@@ -97,7 +97,11 @@ class DatetimeU(PyApiB):
                 if not any(map(lambda x: int(x)==pV,ds)):
                     return False
             return True
-                    
+          
+              
 
-    def now(self, timeFormat='%Y-%m-%d %H:%M:%S'):
+    def nowStr(self, timeFormat='%Y-%m-%d %H:%M:%S')->str:
         return self.dataStr(timeFormat)
+
+    def now(self)->datetime.datetime:
+        return datetime.datetime.now()
\ No newline at end of file
