@@ -16,7 +16,7 @@ class ProxyCrawlerU(PyApiB):
 
     def getProxys(self) -> list:
         """ 获取和解析代理
-        {"host":"xx.xx.xx.xx","port":"xxxx","user":"","pswd":""}
+        {"host":"xx.xx.xx.xx","port":"xxxx","user":"","pswd":"","perSec":"","sourceName":"","expireTime":"","header":"xxx:xxx;zzz:xxx;"}
         """
         return []
     
