@@ -28,10 +28,12 @@ try:
     from ..py_db.mongoDBU import MongoDBU
 except ImportError as e:
     print(e)
+import random
 import time
 CHECK_BAIDU = "https://www.baidu.com"
 DBName = "proxy"
 CHECKED_TBNAME = "checked"
+HEADER_SP = "|~H~|"
 
 class ProxyU(PyApiB):
     """
@@ -42,11 +44,22 @@ class ProxyU(PyApiB):
         return PyApiB._produce(key, __class__)
     
     def __init__(self):
-        self.redis = RedisDBU()
-        self.mongoDB = MongoDBU()
+        self.redis = None
+        try:
+            self.redis = RedisDBU()
+        except Exception as e:
+            pass
+        self.mongoDB = None
+        try:
+            self.mongoDB = MongoDBU()
+        except Exception as e:
+            pass
         self.redisPreKey = "proxyU"
         self.ctrlCU = None
         
+    def setRedisPreKey(self, redisPreKey):
+        self.redisPreKey = redisPreKey
+        
     def addProxyCrawlers(self, crawlers):
         from ..py_mix.moduleU import ModuleU
         cs = ModuleU().importClsByPcls(crawlers,ProxyCrawlerU)
@@ -62,21 +75,6 @@ class ProxyU(PyApiB):
         proxy_crawlers[crawlerName] = crawler
         setattr(self,'proxy_crawlers',proxy_crawlers)
         
-    def getProxyMeta(self,ipSign=None):
-        """ 获取一个代理 """
-        ipSignKey = None if not ipSign else f"{self.redisPreKey}:ipSign:{ipSign}"
-        key = f"{self.redisPreKey}:checked"
-        if ipSignKey:
-            cacheMeta = self.redis.get(ipSignKey)
-            if cacheMeta:
-                return cacheMeta
-        metas = self.redis.srandmember(key)
-        if metas and len(metas)>0:
-            meta = metas[0]
-            if ipSignKey:
-                self.redis.set(ipSignKey,meta,ex=self.getExByIpsign(ipSign))
-            return meta
-        return None
     
     def produceIpSign(self,ex=600):
         """ 生成一个ip标记，如果传入ipSign一样，会尽量返回同一个代理，ex秒后过期 """
@@ -85,18 +83,89 @@ class ProxyU(PyApiB):
     def getExByIpsign(self, ipSign):
         return int(ipSign[-5:])
     
-    def proxyToMeta(self, proxy, ipSign=None):
+    def getProxyMeta(self,ipSign=None, isForNet=True):
+        """ 获取一个代理 """
+        ipSignKey = None if not ipSign else f"{self.redisPreKey}:ipSign:{ipSign}"
+        key = f"{self.redisPreKey}:checked"
+        if ipSignKey:
+            cacheMeta = self.redis.get(ipSignKey)
+            if cacheMeta:
+                return cacheMeta, None
+        _type = self.redis.type(key)
+        metas = []
+        if _type == "list":
+            ll = self.redis.len(key)
+            if ll > 0:
+                ii = random.randint(0,ll-1)
+                metas = self.redis.lrange(key,ii,ii+1)
+        else:
+            metas = self.redis.srandmember(key)
+        if metas and len(metas)>0:
+            meta = metas[0]
+            header = None
+            if isForNet and HEADER_SP in meta:
+                meta,header = meta.split(HEADER_SP)
+            if isForNet and "|" in meta:
+                proxy = self.metaToProxy(meta)
+                meta, header = self.proxyToMeta(proxy, isForNet)
+            if ipSignKey:
+                self.redis.set(ipSignKey,meta,ex=self.getExByIpsign(ipSign))
+            return meta, self.headerTodict(header)
+        return None,None
+    
+    def proxyToMeta(self, proxy, ipSign=None, isForNet=True):
         """ dict的代理转meta格式 """
         if proxy.get("host") == "proxyU":
-            return self.getProxyMeta(ipSign)
+            return self.getProxyMeta(ipSign, isForNet=isForNet)
         if proxy.get("user") and proxy.get("host") and proxy.get("port"):
             meta = f"http://{proxy.get('user')}:{proxy.get('pswd')}@{proxy.get('host')}:{proxy.get('port')}"
         elif proxy.get("host") and proxy.get("port"):
             meta = f"http://{proxy.get('host')}:{proxy.get('port')}"
-        return meta
+        if not isForNet:
+            perSec = proxy.get("perSec","")
+            sourceName = proxy.get("sourceName","")
+            expireTime = proxy.get("expireTime","")
+            header = proxy.get("header")
+            meta = f"{meta}|{perSec}"
+            meta = f"{meta}|{sourceName}"
+            meta = f"{meta}|{expireTime}"
+            if header:
+                meta = f"{meta}{HEADER_SP}{header}"
+        return meta, self.headerTodict(proxy.get("header"))
+    
+    def headerTodict(self, headerStr):
+        if not headerStr:
+            return None
+        header = {}
+        headersStr = []
+        if ";" in headerStr:
+            headersStr = headerStr.split(";")
+        else:
+            headersStr = [headerStr]
+        for h in headersStr:
+            if ":" in h:
+                k,v = h.split(":")
+                if v:
+                    header[k] = v
+        return header
     
     def metaToProxy(self, meta):
         """ meta格式转dict代理 """
+        sourceName = None
+        expireTime = None
+        perSec = None
+        header = None
+        if HEADER_SP in meta:
+            meta, header = meta.split(HEADER_SP)
+        if "|" in meta:
+            metas = meta.split("|")
+            if len(metas) >= 2:
+                meta = metas[0]
+                perSec = metas[1]
+            if len(metas) >= 3:
+                sourceName = metas[2]
+            if len(metas) >= 4:
+                expireTime = metas[3]
         if "//" in meta:
             pInfo = meta.split("//")[1]
             user,pswd = "",""
@@ -108,7 +177,15 @@ class ProxyU(PyApiB):
                     user = up
             if ":" in pInfo:
                 host, port = pInfo.split(":")
-                return {"host":host,"port":port,"user":user,"pswd":pswd}
+                res = {"host":host,"port":port,"user":user,"pswd":pswd}
+                if sourceName:
+                    res["sourceName"] = sourceName
+                    res["perSec"] = perSec
+                if header:
+                    res["header"] = header
+                if expireTime:
+                    res["expireTime"] = expireTime
+                return res
         return {}
         
     def __readLocalMetas(self, type="source", maxLen=1000):
@@ -129,7 +206,9 @@ class ProxyU(PyApiB):
             m1 = meta1.get('meta')
         if isinstance(meta2,dict):
             m2 = meta2.get('meta')
-        return m1 == m2
+        mp1 = self.metaToProxy(m1)
+        mp2 = self.metaToProxy(m2)
+        return all(list(map(lambda x: mp1.get(x)==mp2.get(x),["host","port"])))
     
     def __isInMetas(self, meta1, metas):
         return any(list(map(lambda x: self.__isMetaSame(meta1, x),metas)))
@@ -154,11 +233,19 @@ class ProxyU(PyApiB):
         
     def __filtHasChecked(self, proxys):
         key = f"{self.redisPreKey}:checked"
-        ms = self.redis.srandmember(key)
+        _type = self.redis.type(key)
+        ms = []
+        if _type == "list":
+            ll = self.redis.len(key)
+            if ll > 0:
+                ii = random.randint(0,ll-1)
+                ms = self.redis.lrange(key,ii,ii+1)
+        else:
+            ms = self.redis.srandmember(key)
         newProxys = []
         for proxy in proxys:
-            meta = f"http://{proxy.get('user')}:{proxy.get('pswd')}@{proxy.get('host')}:{proxy.get('port')}"
-            if meta not in ms:
+            meta, header = self.proxyToMeta(proxy, isForNet=False)
+            if not self.__isInMetas(meta, ms):
                 newProxys.append(proxy)
         return newProxys
         
@@ -175,7 +262,7 @@ class ProxyU(PyApiB):
             if isinstance(proxy,str):
                 meta = proxy
             else:
-                meta = self.proxyToMeta(proxy)
+                meta, header = self.proxyToMeta(proxy, isForNet=False)
             if not self.__isInMetas(meta, waitCheckMetas):
                 needPushs.append(meta)
         if needPushs:
@@ -217,15 +304,25 @@ class ProxyU(PyApiB):
         """ 检测一次代理的可用性，并保存入checked。proxyMeta如果为空，则从等待队列中pop一个代理 """
         if proxyMeta == None:
             proxyMeta = self.__popWaitCheck()
-        # print(f"check {proxyMeta}")
         if proxyMeta:
-            res = HttpU().get(checkUrl,proxyMeta=proxyMeta,timeout=timeout)
-            if str(res.get('code')) == "200":
+            isPass = False
+            nowTime = time.time()
+            proxy = self.metaToProxy(proxyMeta)
+            expireTimeStr = proxy.get("expireTime")
+            if not expireTimeStr:
+                expireTimeStr = str(nowTime+604800)
+            expireTime = float(expireTimeStr)
+            if float(expireTime) > nowTime:
+                _proxyMeta, headers = self.proxyToMeta(proxy,isForNet=True)
+                res = HttpU().get(checkUrl,headers=headers,proxyMeta=_proxyMeta,timeout=timeout)
+                if str(res.get('code')) == "200":
+                    isPass = True
+            if isPass:
                 meta = {"meta":proxyMeta,"ut":time.time()}
-                print(f"check {proxyMeta} Pass!!")
+                # print(f"check {proxyMeta} Pass!!")
                 self.__upsertCheckedMeta(meta)
             else:
-                print(f"check {proxyMeta} NoPass!!")
+                # print(f"check {proxyMeta} NoPass!!")
                 self.__removeCheckedMeta(proxyMeta)
             return True
         else:
@@ -262,7 +359,11 @@ class ProxyU(PyApiB):
         key = f"{self.redisPreKey}:checked"
         checkeds = []
         try:
-            checkedset = self.redis.srandmember(key,number=500)
+            _type = self.redis.type(key)
+            if _type == "list":
+                checkedset = self.redis.lrange(key,0,500)
+            else:
+                checkedset = self.redis.srandmember(key,number=500)
             checkeds = list(checkedset)
         except Exception as identifier:
             pass
